Visibilities
============

.. currentmodule:: xrayvision.visibility

.. autoclass:: Visibilities
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~Visibilities.amplitude
      ~Visibilities.amplitude_uncertainty
      ~Visibilities.meta
      ~Visibilities.phase
      ~Visibilities.phase_center
      ~Visibilities.phase_uncertainty
      ~Visibilities.u
      ~Visibilities.uncertainty
      ~Visibilities.v
      ~Visibilities.visibilities

   .. rubric:: Methods Summary

   .. autosummary::

      ~Visibilities.index_by_label

   .. rubric:: Attributes Documentation

   .. autoattribute:: amplitude
   .. autoattribute:: amplitude_uncertainty
   .. autoattribute:: meta
   .. autoattribute:: phase
   .. autoattribute:: phase_center
   .. autoattribute:: phase_uncertainty
   .. autoattribute:: u
   .. autoattribute:: uncertainty
   .. autoattribute:: v
   .. autoattribute:: visibilities

   .. rubric:: Methods Documentation

   .. automethod:: index_by_label
